@@ -6,7 +6,8 @@ from dycow import (
     json_loads,
     BaseHTTPRequestHandler,
     argv,
-    HTTPServer
+    HTTPServer,
+    VERSION
 )
 from dycow.utils import parse_conf_file
 
@@ -25,9 +26,8 @@ class S(BaseHTTPRequestHandler):
         Getting query params
 
         """
-        params = urlparse(self.path).query.split("&")
         q_params = []
-        for p in params:
+        for p in urlparse(self.path).query.split("&"):
             try:
                 q_params.append({"key": p.split("=")[0], "value": p.split("=")[1]})
             except Exception as es:
@@ -35,7 +35,7 @@ class S(BaseHTTPRequestHandler):
 
         return q_params
 
-    def execute_return_res(self, q_params, body_params=None):
+    def execute_return_res(self, q_params: list, body_params=None):
         """
         This method will execute commands and return appropriate response
 
@@ -46,36 +46,33 @@ class S(BaseHTTPRequestHandler):
                     and str(self.path).split("?")[0] == r["url_path"].split("?")[0]:
 
                 res = r["res"]
+                # To create / empty the file
+                open('./out', 'w').close()
                 if body_params is not None and bool(body_params) and r["type"] == "POST":
-                    system("rm -rf ./out && touch out")
                     # it's the good link
                     for cmd in r["command"]:
                         for pr in r["body_params"]:
-                            cmd = cmd.replace("#{}#".format(pr), body_params[pr]) if "#"+pr+"#" in cmd else ""
+                            cmd = cmd.replace("#{}#".format(pr), body_params[pr]) if "#" + pr + "#" in cmd else ""
                         system(cmd + " >> out")
 
                     with open("./out", "r") as out_:
-                        out_content = out_.read()
-                        res = res.replace("#cmd#", out_content)
-                        system("rm -rf ./out")
+                        res = res.replace("#cmd#", out_.read())
 
                     for pr in r["body_params"]:
-                        res = res.replace("#{}#".format(pr), body_params[pr]) if "#"+pr+"#" in res else res
+                        res = res.replace("#{}#".format(pr), body_params[pr]) if "#" + pr + "#" in res else res
                 else:
-                    system("rm -rf ./out && touch out")
                     # it's the good link
                     for cmd in r["command"]:
                         for p in q_params:
-                            cmd = cmd.replace("#{}#".format(p["key"]), p["value"]) if "#"+p["key"]+"#" in cmd else ""
+                            cmd = cmd.replace("#{}#".format(p["key"]), p["value"]) if "#" + p[
+                                "key"] + "#" in cmd else ""
                         system(cmd + " >> out")
 
                     with open("./out", "r") as out_:
-                        out_content = out_.read()
-                        res = res.replace("#cmd#", out_content)
-                        system("rm -rf ./out")
+                        res = res.replace("#cmd#", out_.read())
 
                     for p in q_params:
-                        res = res.replace("#{}#".format(p["key"]), p["value"]) if "#"+p["key"]+"#" in res else res
+                        res = res.replace("#{}#".format(p["key"]), p["value"]) if "#" + p["key"] + "#" in res else res
 
         return res
 
@@ -100,7 +97,7 @@ class S(BaseHTTPRequestHandler):
         content_length = int(self.headers['Content-Length'])  # <--- Gets the size of data
         post_data = self.rfile.read(content_length)  # <--- Gets the data itself
         print("[-] POST request,\nPath: {}\nHeaders:\n{}\n\nBody:\n{}\n".format(str(self.path), str(self.headers),
-                                                                            post_data.decode('utf-8')))
+                                                                                post_data.decode('utf-8')))
         # We get query params
         q_params = self.get_queries()
         # We get body params
@@ -116,8 +113,9 @@ def run(server_class=HTTPServer, handler_class=S, port=8080):
     """
     The runner function
     """
+    print("- " * 30)
     httpd = server_class(('', port), handler_class)
-    print('[-] Starting dycow, port<{}>, conf-file<{}>...\n'.format(port, CONF_FILE))
+    print('[-] Starting dycow instance...\n[-] On port<{}>, conf<{}>...\n'.format(port, CONF_FILE))
     try:
         httpd.serve_forever()
     except KeyboardInterrupt:
@@ -129,7 +127,7 @@ def run(server_class=HTTPServer, handler_class=S, port=8080):
 
 
 def help_center():
-    print("[x] Help center !\n[x] Run : dw <port> <conf-file> \n"
+    print("[-] dycow v" + VERSION + ".\n[-] Help center !\n[x] Run : dw <port> <conf-file> \n"
           "[x] Documentation online https://github.com/sanix-darker/dycow")
 
 
@@ -141,18 +139,13 @@ if __name__ == '__main__':
         if path.exists(CONF_FILE):
             # We check if the port is a numeric value
             if argv[1].isnumeric():
-                print("- " * 30)
                 # We parse and get requests as dict from the configuration file
                 REQS = parse_conf_file(CONF_FILE)
                 # We start the server
                 run(port=int(argv[1]))
             else:
-                print("[x] Port Error !\n[x] Run : dw <port> <conf-file> \n"
-                      "[x] Documentation online https://github.com/sanix-darker/dycow")
+                help_center()
         else:
             print("[x] Error !\n[x] This file '{}' doesn't exist !".format(CONF_FILE))
-    elif len(argv) <= 2:
-        help_center()
     else:
-        print("[x] Error !\n[x] Run : dw <port> <conf-file> \n"
-              "[x] Documentation online https://github.com/sanix-darker/dycow")
+        help_center()
